# [1.8.7](https://github.com/seriaati/ambr/compare/v1.8.6..v1.8.7) - 2025-09-10

## Bug Fixes

- Fix City enum not exported - ([349a253](https://github.com/seriaati/ambr/commit/349a253bc093b1930ead9825357d14fa09ba7bd7))

## Features

- Add Nod-Krai to City enum - ([04a9bfb](https://github.com/seriaati/ambr/commit/04a9bfb55d87b934da799ec21d6689d49b8716d0))
- Add a BaseModel with shared model config & post-processing - ([716404a](https://github.com/seriaati/ambr/commit/716404a8a13ad577e1f6391d4a647c1f9a25ed5a))

## Miscellaneous Chores

- **(deps)** lock file maintenance (#116) - ([3fb5040](https://github.com/seriaati/ambr/commit/3fb50406831121d8c51b240a1cf817366fca2acd))
- **(deps)** update actions/setup-python action to v6 (#117) - ([486ab93](https://github.com/seriaati/ambr/commit/486ab93f2566f441ffd856d6c8204eb0d0945320))
- **(deps)** lock file maintenance (#118) - ([525da21](https://github.com/seriaati/ambr/commit/525da210770c28960679ec18e8666e905b546607))

## Refactoring

- Use BaseModel & remove redundant method calls - ([a945e21](https://github.com/seriaati/ambr/commit/a945e2181cb4afe606ad34e7891043861437790d))

<!-- generated by git-cliff -->
